@@ -1,6 +1,6 @@
 package PGObject::Util::DBChange;
 
-use 5.010; # double forward slash requires 5.10
+use 5.006;
 use strict;
 use warnings;
 
@@ -13,15 +13,15 @@ use Moo;
 
 =head1 NAME
 
-PGObject::Util::DBChange - Track applied change files in the database
+PGObject::Util::DBChange - The great new PGObject::Util::DBChange!
 
 =head1 VERSION
 
-Version 0.050.4
+Version 0.01
 
 =cut
 
-our $VERSION = '0.050.4';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -201,7 +201,7 @@ Runs against the current dbh without tracking.
 
 sub run {
     my ($self, $dbh) = @_;
-    $dbh->do($self->content); # not raw
+    $dbh->do($self->_wrap_transaction($self->content)); # not raw
 }
 
 =head2 apply($dbh)
@@ -236,13 +236,12 @@ sub apply {
         $dbh->commit if $need_commit;
     }
     my $success = eval {
-         $dbh->do($self->content_wrapped($before, $after));
+         $dbh->prepare($self->content_wrapped($before, $after))->execute();
     };
     $dbh->commit if $need_commit;
     die "$DBI::state: $DBI::errstr" unless $success or $no_transactions;
     $self->log(dbh => $dbh, state => $DBI::state, errstr => $DBI::errstr) 
        if $log;
-    return 1;
 }
 
 sub log {
@@ -375,7 +374,7 @@ Many thanks to Sedex Global for their sponsorship of portions of the module.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016, 2017 Chris Travers.
+Copyright 2016 The LedgerSMB Core Team.
 
 This program is distributed under the (Revised) BSD License:
 L<http://www.opensource.org/licenses/BSD-3-Clause>
